==> metasdk-1.9.3.tar.gz: metasdk-1.9.3/README.md <==
# MetaSDK Python

[Документация](http://metasdk.readthedocs.io/)

[Полный список примеров](https://github.com/devision-io/metasdk/tree/master/metasdk/examples/)

### Как обновить metasdk в pypi.org

1. Если кто-то из новых людей будет пробовать обновлять - надо дописать гайд как зарегаться на pypi.org и получить возможность обновлять метасдк

2. Обновляем наш репозиторий в соответствии с общими правилами, не забываем апнуть версию (version) в info.py, как обычно в пайтон-либах (на момент написания это - обновляем мастер, создаём ветку с номером задачи из мастера, заливаем коммиты в ветку, создаём пулл-реквест в стеше, при необходимости мержимся с актуальным мастером, проходим ревью, заливаем в мастер)

3. Если не устанавливали, устанавливаем pip3 install wheel && pip3 install twine (если ещё не делали (это как раз тот этап, когда у кого-то может деплоиться, а у кого-то нет)

4. Делаем make publish. С 1 января 2024 года pypi больше не использует логин/пароль юзера для обновления проектов. Теперь сначала нужно включить двухфакторную аутентификацию.
Затем можно выпустить API токен для своего аккаунта. При make publish передать в username: "__token__", в password: <полученый токен>. Подробности: https://pypi.org/help/#apitoken

5. Обновить версию в тех репозиториях, для которых, собственно, делаются изменения (например, metafeedconnectors)


### Рекомендации пользователям MetaSDK Python
- Не устанавливать отдельно зависимости прописанные в MetaSDK. Например: библиотеку requests.

Связанные задачи:
- META-2941
- META-2571

==> metasdk-1.10.2.tar.gz: metasdk-1.10.2/README.md <==
# MetaSDK Python

[Документация](http://metasdk.readthedocs.io/)

[Полный список примеров](https://github.com/devision-io/metasdk/tree/master/metasdk/examples/)

### Как обновить metasdk в pypi.org

1. Если кто-то из новых людей будет пробовать обновлять - надо дописать гайд как зарегаться на pypi.org и получить возможность обновлять метасдк

2. Обновляем наш репозиторий в соответствии с общими правилами, не забываем апнуть версию (version) в info.py, как обычно в пайтон-либах (на момент написания это - обновляем мастер, создаём ветку с номером задачи из мастера, заливаем коммиты в ветку, создаём пулл-реквест в стеше, при необходимости мержимся с актуальным мастером, проходим ревью, заливаем в мастер)

3. Если не устанавливали, устанавливаем pip3 install wheel && pip3 install twine (это как раз тот этап, когда у кого-то может деплоиться, а у кого-то нет)

4. Делаем make publish. С 1 января 2024 года pypi больше не использует логин/пароль юзера для обновления проектов. Теперь сначала нужно включить двухфакторную аутентификацию.
Затем можно выпустить API токен для своего аккаунта. При make publish передать в username: "__token__", в password: <полученый токен>. Подробности: https://pypi.org/help/#apitoken

5. Обновить версию в тех репозиториях, для которых, собственно, делаются изменения (например, metafeedconnectors)


### Рекомендации пользователям MetaSDK Python
- Не устанавливать отдельно зависимости прописанные в MetaSDK. Например: библиотеку requests.

Связанные задачи:
- META-2941
- META-2571
